@@ -40,20 +40,13 @@
 #include <string.h>
 #include <gio/gio.h>
 
-#define GTR_ASSISTANT_GET_PRIVATE(object)	(G_TYPE_INSTANCE_GET_PRIVATE ( \
-						 (object),	\
-						 GTR_TYPE_ASSISTANT,     \
-						 GtrAssistantPrivate))
-
-
-G_DEFINE_TYPE (GtrAssistant, gtr_assistant, GTK_TYPE_ASSISTANT)
-
-struct _GtrAssistantPrivate
+typedef struct
 {
   /* Profiles Page 1 */
   GtkWidget *profile_name;
   GtkWidget *name;
   GtkWidget *email;
+  GtkWidget *team_email;
 
   /* Profiles Page 2 */
   GtkWidget *languages_fetcher;
@@ -61,7 +54,10 @@ struct _GtrAssistantPrivate
   /* Confirmation Page */
   GtkWidget *finish_box;
   GtkWidget *confirm_label;
-};
+} GtrAssistantPrivate;
+
+G_DEFINE_TYPE_WITH_CODE (GtrAssistant, gtr_assistant, GTK_TYPE_ASSISTANT,
+                         G_ADD_PRIVATE (GtrAssistant))
 
 static void
 on_assistant_close (GtkAssistant * assistant)
@@ -75,39 +71,40 @@ on_assistant_apply (GtkAssistant * assistant)
   GtrAssistant *as = GTR_ASSISTANT (assistant);
   GtrProfile *profile;
   GtrProfileManager *prof_manager;
+  GtrAssistantPrivate *priv = gtr_assistant_get_instance_private (as);
 
   profile = gtr_profile_new ();
   prof_manager = gtr_profile_manager_get_default ();
 
   gtr_profile_set_name (profile,
                         gtk_entry_get_text (GTK_ENTRY
-                                            (as->priv->profile_name)));
+                                            (priv->profile_name)));
 
   gtr_profile_set_author_name (profile,
                                gtk_entry_get_text (GTK_ENTRY
-                                                   (as->priv->name)));
+                                                   (priv->name)));
 
   gtr_profile_set_author_email (profile,
                                 gtk_entry_get_text (GTK_ENTRY
-                                                    (as->priv->email)));
-
-  gtr_profile_set_language_name (profile,
-                                 gtr_languages_fetcher_get_language_name (GTR_LANGUAGES_FETCHER (as->priv->languages_fetcher)));
-
-  gtr_profile_set_language_code (profile,
-                                 gtr_languages_fetcher_get_language_code (GTR_LANGUAGES_FETCHER (as->priv->languages_fetcher)));
-
-  gtr_profile_set_charset (profile,
-                           gtr_languages_fetcher_get_charset (GTR_LANGUAGES_FETCHER (as->priv->languages_fetcher)));
-
-  gtr_profile_set_encoding (profile,
-                            gtr_languages_fetcher_get_encoding (GTR_LANGUAGES_FETCHER (as->priv->languages_fetcher)));
+                                                    (priv->email)));
 
   gtr_profile_set_group_email (profile,
-                               gtr_languages_fetcher_get_team_email (GTR_LANGUAGES_FETCHER (as->priv->languages_fetcher)));
+                               gtk_entry_get_text (GTK_ENTRY (priv->team_email)));
+
+  gtr_profile_set_language_name (profile,
+                                 gtr_languages_fetcher_get_language_name (GTR_LANGUAGES_FETCHER (priv->languages_fetcher)));
+
+  gtr_profile_set_language_code (profile,
+                                 gtr_languages_fetcher_get_language_code (GTR_LANGUAGES_FETCHER (priv->languages_fetcher)));
+
+  gtr_profile_set_charset (profile,
+                           gtr_languages_fetcher_get_charset (GTR_LANGUAGES_FETCHER (priv->languages_fetcher)));
+
+  gtr_profile_set_encoding (profile,
+                            gtr_languages_fetcher_get_encoding (GTR_LANGUAGES_FETCHER (priv->languages_fetcher)));
 
   gtr_profile_set_plural_forms (profile,
-                                gtr_languages_fetcher_get_plural_form (GTR_LANGUAGES_FETCHER (as->priv->languages_fetcher)));
+                                gtr_languages_fetcher_get_plural_form (GTR_LANGUAGES_FETCHER (priv->languages_fetcher)));
 
   /* Add profile to profile manager and save it */
   gtr_profile_manager_add_profile (prof_manager, profile);
@@ -122,9 +119,10 @@ static void
 on_assistant_prepare (GtkAssistant * assistant, GtkWidget * page)
 {
   GtrAssistant *as = GTR_ASSISTANT (assistant);
+  GtrAssistantPrivate *priv = gtr_assistant_get_instance_private (as);
   gchar *string;
 
-  if (page != as->priv->finish_box)
+  if (page != priv->finish_box)
     return;
 
   string = g_strdup_printf (_("Profile name: %s\n"
@@ -137,17 +135,17 @@ on_assistant_prepare (GtkAssistant * assistant, GtkWidget * page)
                               "Transfer encoding: %s\n"
                               "Plural form: %s\n"),
                             gtk_entry_get_text (GTK_ENTRY
-                                                (as->priv->profile_name)),
-                            gtk_entry_get_text (GTK_ENTRY (as->priv->name)),
-                            gtk_entry_get_text (GTK_ENTRY (as->priv->email)),
-                            gtr_languages_fetcher_get_language_name (GTR_LANGUAGES_FETCHER (as->priv->languages_fetcher)),
-                            gtr_languages_fetcher_get_team_email (GTR_LANGUAGES_FETCHER (as->priv->languages_fetcher)),
-                            gtr_languages_fetcher_get_language_code (GTR_LANGUAGES_FETCHER (as->priv->languages_fetcher)),
-                            gtr_languages_fetcher_get_charset (GTR_LANGUAGES_FETCHER (as->priv->languages_fetcher)),
-                            gtr_languages_fetcher_get_encoding (GTR_LANGUAGES_FETCHER (as->priv->languages_fetcher)),
-                            gtr_languages_fetcher_get_plural_form (GTR_LANGUAGES_FETCHER (as->priv->languages_fetcher)));
+                                                (priv->profile_name)),
+                            gtk_entry_get_text (GTK_ENTRY (priv->name)),
+                            gtk_entry_get_text (GTK_ENTRY (priv->email)),
+                            gtr_languages_fetcher_get_language_name (GTR_LANGUAGES_FETCHER (priv->languages_fetcher)),
+                            gtk_entry_get_text (GTK_ENTRY (priv->team_email)),
+                            gtr_languages_fetcher_get_language_code (GTR_LANGUAGES_FETCHER (priv->languages_fetcher)),
+                            gtr_languages_fetcher_get_charset (GTR_LANGUAGES_FETCHER (priv->languages_fetcher)),
+                            gtr_languages_fetcher_get_encoding (GTR_LANGUAGES_FETCHER (priv->languages_fetcher)),
+                            gtr_languages_fetcher_get_plural_form (GTR_LANGUAGES_FETCHER (priv->languages_fetcher)));
 
-  gtk_label_set_text (GTK_LABEL (as->priv->confirm_label), string);
+  gtk_label_set_text (GTK_LABEL (priv->confirm_label), string);
   g_free (string);
 }
 
@@ -183,12 +181,13 @@ on_profile1_entry_changed (GtkWidget * widget, GtrAssistant * as)
   const gchar *text;
   GtkWidget *current_page;
   gint page_number;
+  GtrAssistantPrivate *priv = gtr_assistant_get_instance_private (as);
 
   page_number = gtk_assistant_get_current_page (GTK_ASSISTANT (as));
   current_page = gtk_assistant_get_nth_page (GTK_ASSISTANT (as), page_number);
 
   /* Profile name */
-  text = gtk_entry_get_text (GTK_ENTRY (as->priv->profile_name));
+  text = gtk_entry_get_text (GTK_ENTRY (priv->profile_name));
 
   if (text && *text)
     gtk_assistant_set_page_complete (GTK_ASSISTANT (as), current_page, TRUE);
@@ -200,7 +199,7 @@ on_profile1_entry_changed (GtkWidget * widget, GtrAssistant * as)
     }
 
   /* Translator name */
-  text = gtk_entry_get_text (GTK_ENTRY (as->priv->name));
+  text = gtk_entry_get_text (GTK_ENTRY (priv->name));
 
   if (text && *text)
     gtk_assistant_set_page_complete (GTK_ASSISTANT (as), current_page, TRUE);
@@ -212,7 +211,19 @@ on_profile1_entry_changed (GtkWidget * widget, GtrAssistant * as)
     }
 
   /* Translator email */
-  text = gtk_entry_get_text (GTK_ENTRY (as->priv->email));
+  text = gtk_entry_get_text (GTK_ENTRY (priv->email));
+
+  if (text && *text)
+    gtk_assistant_set_page_complete (GTK_ASSISTANT (as), current_page, TRUE);
+  else
+    {
+      gtk_assistant_set_page_complete (GTK_ASSISTANT (as), current_page,
+                                       FALSE);
+      return;
+    }
+
+  /* Team email */
+  text = gtk_entry_get_text (GTK_ENTRY (priv->team_email));
 
   if (text && *text)
     gtk_assistant_set_page_complete (GTK_ASSISTANT (as), current_page, TRUE);
@@ -229,7 +240,7 @@ create_profiles_page1 (GtrAssistant * as)
 {
   GtkWidget *box, *hbox;
   GtkWidget *label;
-  GtrAssistantPrivate *priv = as->priv;
+  GtrAssistantPrivate *priv = gtr_assistant_get_instance_private (as);
   gchar *markup;
 
   box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
@@ -244,10 +255,11 @@ create_profiles_page1 (GtrAssistant * as)
   gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, 0);
 
   label = gtk_label_new (NULL);
-  markup = g_strdup_printf("<b>%s</b>", _("Profile name:"));
-  g_free(markup);
+  markup = g_strdup_printf("<b>%s</b>", _("Profile name"));
   gtk_label_set_markup (GTK_LABEL (label), markup);
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+  g_free(markup);
+  gtk_label_set_xalign (GTK_LABEL (label), 1.0);
+  gtk_label_set_yalign (GTK_LABEL (label), 0.5);
   gtk_widget_show (label);
   gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
 
@@ -265,10 +277,11 @@ create_profiles_page1 (GtrAssistant * as)
   gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, 0);
 
   label = gtk_label_new (NULL);
-  markup = g_strdup_printf("<b>%s</b>", ("Translator name:"));
+  markup = g_strdup_printf("<b>%s</b>", ("Translator name"));
   gtk_label_set_markup (GTK_LABEL (label), markup);
   g_free(markup);
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+  gtk_label_set_xalign (GTK_LABEL (label), 1.0);
+  gtk_label_set_yalign (GTK_LABEL (label), 0.5);
   gtk_widget_show (label);
   gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
 
@@ -286,10 +299,11 @@ create_profiles_page1 (GtrAssistant * as)
   gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, 0);
 
   label = gtk_label_new (NULL);
-  markup = g_strdup_printf("<b>%s</b>", _("Translator email:"));
+  markup = g_strdup_printf("<b>%s</b>", _("Translator email"));
   gtk_label_set_markup (GTK_LABEL (label), markup);
   g_free(markup);
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+  gtk_label_set_xalign (GTK_LABEL (label), 1.0);
+  gtk_label_set_yalign (GTK_LABEL (label), 0.5);
   gtk_widget_show (label);
   gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
 
@@ -299,14 +313,42 @@ create_profiles_page1 (GtrAssistant * as)
   g_signal_connect (G_OBJECT (priv->email), "changed",
                     G_CALLBACK (on_profile1_entry_changed), as);
 
+  /*
+   * Team email:
+   */
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
+  gtk_widget_show (hbox);
+  gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, 0);
+
+  label = gtk_label_new (NULL);
+  markup = g_strdup_printf("<b>%s</b>", _("Team email"));
+  gtk_label_set_markup (GTK_LABEL (label), markup);
+  g_free(markup);
+  gtk_label_set_xalign (GTK_LABEL (label), 1.0);
+  gtk_label_set_yalign (GTK_LABEL (label), 0.5);
+  gtk_widget_show (label);
+  gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
+
+  priv->team_email = gtk_entry_new ();
+  gtk_widget_show (priv->team_email);
+  gtk_box_pack_start (GTK_BOX (hbox), priv->team_email, FALSE, FALSE, 0);
+  g_signal_connect (G_OBJECT (priv->team_email), "changed",
+                    G_CALLBACK (on_profile1_entry_changed), as);
+
   gtk_assistant_append_page (GTK_ASSISTANT (as), box);
   gtk_assistant_set_page_title (GTK_ASSISTANT (as), box, _("Profile"));
+
+  /**
+   * Default values
+   */
+  gtk_entry_set_text (GTK_ENTRY (priv->profile_name), "default");
+  gtk_entry_set_text (GTK_ENTRY (priv->name), g_get_real_name ());
 }
 
 static void
 on_profile2_entry_changed (GtkWidget * widget, GtrAssistant * as)
 {
-  GtrAssistantPrivate *priv = as->priv;
+  GtrAssistantPrivate *priv = gtr_assistant_get_instance_private (as);
   const gchar *text;
   GtkWidget *current_page;
   gint page_number;
@@ -362,14 +404,6 @@ on_profile2_entry_changed (GtkWidget * widget, GtrAssistant * as)
       return;
     }
 
-  /* Team email */
-  text = gtr_languages_fetcher_get_team_email (GTR_LANGUAGES_FETCHER (priv->languages_fetcher));
-
-  if (text && *text)
-    gtk_assistant_set_page_complete (GTK_ASSISTANT (as), current_page, TRUE);
-  else
-    gtk_assistant_set_page_complete (GTK_ASSISTANT (as), current_page, FALSE);
-
   /* Plural form */
   text = gtr_languages_fetcher_get_plural_form (GTR_LANGUAGES_FETCHER (priv->languages_fetcher));
 
@@ -382,7 +416,7 @@ on_profile2_entry_changed (GtkWidget * widget, GtrAssistant * as)
 static void
 create_profiles_page2 (GtrAssistant * as)
 {
-  GtrAssistantPrivate *priv = as->priv;
+  GtrAssistantPrivate *priv = gtr_assistant_get_instance_private (as);
 
   priv->languages_fetcher = gtr_languages_fetcher_new ();
   gtk_widget_show (priv->languages_fetcher);
@@ -392,35 +426,33 @@ create_profiles_page2 (GtrAssistant * as)
                     as);
 
   gtk_assistant_append_page (GTK_ASSISTANT (as), priv->languages_fetcher);
-  gtk_assistant_set_page_title (GTK_ASSISTANT (as), priv->languages_fetcher, _("Profile"));
+  gtk_assistant_set_page_title (GTK_ASSISTANT (as), priv->languages_fetcher, _("Language"));
 }
 
 static void
 create_finish_page (GtrAssistant * as)
 {
-  as->priv->finish_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-  gtk_widget_show (as->priv->finish_box);
+  GtrAssistantPrivate *priv = gtr_assistant_get_instance_private (as);
+  priv->finish_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+  gtk_widget_show (priv->finish_box);
 
-  as->priv->confirm_label = gtk_label_new (NULL);
-  gtk_widget_show (as->priv->confirm_label);
-  gtk_box_pack_start (GTK_BOX (as->priv->finish_box), as->priv->confirm_label,
+  priv->confirm_label = gtk_label_new (NULL);
+  gtk_widget_show (priv->confirm_label);
+  gtk_box_pack_start (GTK_BOX (priv->finish_box), priv->confirm_label,
                       TRUE, TRUE, 0);
 
-  gtk_assistant_append_page (GTK_ASSISTANT (as), as->priv->finish_box);
-  gtk_assistant_set_page_type (GTK_ASSISTANT (as), as->priv->finish_box,
+  gtk_assistant_append_page (GTK_ASSISTANT (as), priv->finish_box);
+  gtk_assistant_set_page_type (GTK_ASSISTANT (as), priv->finish_box,
                                GTK_ASSISTANT_PAGE_CONFIRM);
-  gtk_assistant_set_page_complete (GTK_ASSISTANT (as), as->priv->finish_box,
+  gtk_assistant_set_page_complete (GTK_ASSISTANT (as), priv->finish_box,
                                    TRUE);
-  gtk_assistant_set_page_title (GTK_ASSISTANT (as), as->priv->finish_box,
+  gtk_assistant_set_page_title (GTK_ASSISTANT (as), priv->finish_box,
                                 _("Confirmation"));
 }
 
 static void
 gtr_assistant_init (GtrAssistant * as)
 {
-  as->priv = GTR_ASSISTANT_GET_PRIVATE (as);
-
-  //gtk_window_set_default_size (GTK_WINDOW (as), 300, 200);
   gtk_window_set_resizable (GTK_WINDOW (as), TRUE);
   gtk_window_set_destroy_with_parent (GTK_WINDOW (as), TRUE);
 
@@ -442,8 +474,6 @@ gtr_assistant_class_init (GtrAssistantClass * klass)
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   GtkAssistantClass *assistant_class = GTK_ASSISTANT_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (GtrAssistantPrivate));
-
   object_class->finalize = gtr_assistant_finalize;
   assistant_class->prepare = on_assistant_prepare;
   assistant_class->apply = on_assistant_apply;
@@ -468,14 +498,11 @@ gtr_show_assistant (GtrWindow * window)
       gtk_widget_show (GTK_WIDGET (assist));
     }
 
+  gtk_window_set_transient_for (GTK_WINDOW (assist), GTK_WINDOW (window));
+  gtk_window_set_attached_to (GTK_WINDOW (assist), GTK_WIDGET (window));
+  gtk_window_set_type_hint (GTK_WINDOW (assist), GDK_WINDOW_TYPE_HINT_DIALOG);
   /* Make asssitant modal preventing using application without profile */
   gtk_window_set_modal (GTK_WINDOW (assist), TRUE);
 
-  if (GTK_WINDOW (window) !=
-      gtk_window_get_transient_for (GTK_WINDOW (assist)))
-    {
-      gtk_window_set_transient_for (GTK_WINDOW (assist), GTK_WINDOW (window));
-    }
-
   gtk_window_present (GTK_WINDOW (assist));
 }
