@@ -2,12 +2,12 @@
  * gtr-close-confirmation-dialog.c
  * This file is part of gtranslator
  *
- * Copyright (C) 2004-2005 GNOME Foundation 
- *	         2008 Ignacio Casal Quinteiro
+ * Copyright (C) 2004-2005  GNOME Foundation
+ *               2008 Ignacio Casal Quinteiro
  *
- * This program is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
