@@ -115,6 +115,18 @@ GtrProfile      *gtr_header_get_profile              (GtrHeader *header);
 
 gchar           *gtr_header_get_language_code        (GtrHeader * header);
 
+gchar           *gtr_header_get_dl_team              (GtrHeader * header);
+gchar           *gtr_header_get_dl_module            (GtrHeader * header);
+gchar           *gtr_header_get_dl_branch            (GtrHeader * header);
+gchar           *gtr_header_get_dl_domain            (GtrHeader * header);
+gchar           *gtr_header_get_dl_state             (GtrHeader * header);
+
+void            gtr_header_set_dl_info               (GtrHeader * header,
+                                                      const gchar * team,
+                                                      const gchar * module_name,
+                                                      const gchar * branch,
+                                                      const gchar * domain);
+
 G_END_DECLS
 
 #endif /* __HEADER_H__ */
